/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.plugins.clover;

import org.apache.commons.configuration.Configuration;
import org.apache.maven.plugin.logging.Log;
import org.sonar.plugins.api.maven.AbstractMavenPluginHandler;
import org.sonar.plugins.api.maven.model.MavenPlugin;
import org.sonar.plugins.api.maven.model.MavenPom;

public abstract class AbstractCloverMavenPluginHandler extends AbstractMavenPluginHandler {
  private Log log;
  private Configuration configuration;

  protected AbstractCloverMavenPluginHandler(Configuration configuration, Log log) {
    this.configuration = configuration;
    this.log = log;
  }

  public boolean isFixedVersion() {
    return false;
  }

  public String[] getGoals() {
    return new String[]{"instrument", "clover"};
  }

  public boolean shouldStopOnFailure() {
    return true;
  }

  protected abstract String getPropKeyLicense();

  protected abstract int getCloverMajorVersion();

  @Override
  public void configurePlugin(MavenPom pom, MavenPlugin plugin) {
    configureParameters(pom, plugin);
    configureLicense(pom, plugin);
  }

  protected void configureParameters(MavenPom pom, MavenPlugin plugin) {
    plugin.unsetConfigParameter("outputDirectory");
    plugin.setConfigParameter("generateXml", "true");
    String javaVersion = pom.getJavaVersion();
    if (javaVersion != null) {
      plugin.setConfigParameter("jdk", javaVersion);
    }
  }

  protected void configureLicense(MavenPom pom, MavenPlugin plugin) {
    CloverMavenPlugin cloverMavenPlugin = new CloverMavenPlugin(plugin, getCloverMajorVersion(), getPropKeyLicense(), log, configuration);
    if (!cloverMavenPlugin.isLocalLicenseContentExisting()) {
      plugin.setConfigParameter("licenseLocation", cloverMavenPlugin.getOrCreateLicensePath(pom));
    }
  }

}
